# deprecation_rails [![Build Status](https://travis-ci.org/jeyb/deprecation_rails.png)](https://travis-ci.org/jeyb/deprecation_rails)
Deprecation policies for your Rails application.

## Usage
Deprecations can occur on classes or methods.

### Deprecating classes
```ruby
class Array
  include Deprecation::Notifier # Rails controllers and models will have this included by default.
  deprecate at: Date.parse("2013-01-12"), message: "Use BetterArray instead."
end
```

This will output:
```
DEPRECATION WARNING: Array is deprecated as of 2013-01-12 00:00:00 -0800. Use BetterArray instead. (called from block (2 levels) in <top (required)> at /../array.rb:11)
```

### Deprecating methods
```ruby
class Array
  include Deprecation::Notifier # Rails controllers and models will have this included by default.

  def id
    object_id
  end
  deprecate :id, at: Date.parse("2013-01-12"), message: "Use object_id instead."
end
```

This will output:
```
DEPRECATION WARNING: Array#id is deprecated as of 2013-01-12 00:00:00 -0800. Use object_id instead. (called from block (2 levels) in <top (required)> at /../array.rb:4)
```

## Contributing to deprecation_rails
* Check out the latest master to make sure the feature hasn't been implemented or the bug hasn't been fixed yet.
* Check out the issue tracker to make sure someone already hasn't requested it and/or contributed it.
* Fork the project.
* Start a feature/bugfix branch.
* Commit and push until you are happy with your contribution.
* Make sure to add tests for it. This is important so I don't break it in a future version unintentionally.
* Please try not to mess with the Rakefile, version, or history. If you want to have your own version, or is otherwise necessary, that is fine, but please isolate to its own commit so I can cherry-pick around it.

## Copyright
Copyright (c) 2013 Jey Balachandran. See LICENSE for further details.
