require "spec_helper"

class DeprecatedMethodsTest
  include Deprecation::Notifier
  DAY = 24 * 60 * 60

  def deprecated_method
  end
  deprecate :deprecated_method

  def deprecated_method_with_custom_message
  end
  deprecate :deprecated_method_with_custom_message, message: "That Shit Cray"

  def deprecated_method_as_of_yesterday
  end
  deprecate :deprecated_method_as_of_yesterday, at: Time.now - DAY

  def deprecated_method_starting_tomorrow
  end
  deprecate :deprecated_method_starting_tomorrow, at: Time.now + DAY

  def undeprecated_method
  end
end

describe Deprecation do
  subject { DeprecatedMethodsTest.new }

  it "calls the deprecation logger when the method is deprecated" do
    ActiveSupport::Deprecation.should_receive(:warn)
    subject.deprecated_method
  end

  it "calls the deprecation logger when the method is deprecated with a custom message" do
    ActiveSupport::Deprecation.should_receive(:warn)
    subject.deprecated_method_with_custom_message
  end

  it "calls the deprecation logger for methods deprecated as of yesterday" do
    ActiveSupport::Deprecation.should_receive(:warn)
    subject.deprecated_method_as_of_yesterday
  end

  it "doesn't call the deprecation logger when the method isn't deprecated" do
    ActiveSupport::Deprecation.should_not_receive(:warn)
    subject.undeprecated_method
  end

  it "doesn't call the deprecation logger for methods deprecated starting tomorrow" do
    ActiveSupport::Deprecation.should_not_receive(:warn)
    subject.deprecated_method_starting_tomorrow
  end

  it "calls the deprecation logger when the class is defined" do
    ActiveSupport::Deprecation.should_receive(:warn).once

    class DeprecatedClassTest
      include Deprecation::Notifier
      deprecate

      def undeprecated_method
      end
    end

    subject = DeprecatedClassTest.new
    subject.undeprecated_method
  end

  it "doesn't call the deprecation logger when the class is defined for class deprecated starting tomorrow" do
    ActiveSupport::Deprecation.should_not_receive(:warn)

    class DeprecatedClassTest
      include Deprecation::Notifier
      deprecate at: Time.now + DeprecatedMethodsTest::DAY

      def undeprecated_method
      end
    end

    subject = DeprecatedClassTest.new
    subject.undeprecated_method
  end
end
